@@ -38,15 +38,15 @@ class ImageMetaInfoDialog : public QDialog
 {
     Q_OBJECT
 public:
-    ImageMetaInfoDialog(QWidget* parent);
-    ~ImageMetaInfoDialog();
+    explicit ImageMetaInfoDialog(QWidget* parent);
+    ~ImageMetaInfoDialog() Q_DECL_OVERRIDE;
 
     /**
      * Defines the image metainfo model and the preferred metainfo key list.
      */
     void setMetaInfo(ImageMetaInfoModel*, const QStringList& list);
 
-    virtual QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const Q_DECL_OVERRIDE;
 
 Q_SIGNALS:
     void preferredMetaInfoKeyListChanged(const QStringList&);
