@@ -31,6 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QCursor>
 #include <QGraphicsSceneMouseEvent>
 #include <QStandardPaths>
+#include <QPainter>
 
 namespace Gwenview
 {
@@ -58,6 +59,8 @@ struct AbstractImageViewPrivate
     QPointF mLastDragPos;
     QSizeF mDocumentSize;
 
+    const QPixmap mAlphaBackgroundTexture = createAlphaBackgroundTexture();
+
     void adjustImageOffset(Verbosity verbosity = Notify)
     {
         QSizeF zoomedDocSize = q->documentSize() * mZoom;
@@ -111,6 +114,28 @@ struct AbstractImageViewPrivate
         QPixmap cursorPixmap = QPixmap(path);
         mZoomCursor = QCursor(cursorPixmap, 11, 11);
     }
+
+    QPixmap createAlphaBackgroundTexture()
+    {
+        QPixmap pix = QPixmap(32, 32);
+        QPainter painter(&pix);
+        painter.fillRect(pix.rect(), QColor(128, 128, 128));
+        const QColor light = QColor(192, 192, 192);
+        painter.fillRect(0, 0, 16, 16, light);
+        painter.fillRect(16, 16, 16, 16, light);
+        return pix;
+    }
+
+    void checkAndRequestZoomAction(const QGraphicsSceneMouseEvent* event)
+    {
+        if (event->modifiers() & Qt::ControlModifier) {
+            if (event->button() == Qt::LeftButton) {
+                q->zoomInRequested(event->pos());
+            } else if (event->button() == Qt::RightButton) {
+                q->zoomOutRequested(event->pos());
+            }
+        }
+    }
 };
 
 AbstractImageView::AbstractImageView(QGraphicsItem* parent)
@@ -127,6 +152,7 @@ AbstractImageView::AbstractImageView(QGraphicsItem* parent)
     d->mScrollPos = QPointF(0, 0);
     setFocusPolicy(Qt::WheelFocus);
     setFlag(ItemIsSelectable);
+    setFlag(ItemClipsChildrenToShape);
     setAcceptHoverEvents(true);
     d->setupZoomCursor();
     updateCursor();
@@ -148,7 +174,7 @@ Document::Ptr AbstractImageView::document() const
 void AbstractImageView::setDocument(Document::Ptr doc)
 {
     if (d->mDocument) {
-        disconnect(d->mDocument.data(), 0, this, 0);
+        disconnect(d->mDocument.data(), nullptr, this, nullptr);
     }
     d->mDocument = doc;
     loadFromDocument();
@@ -242,6 +268,7 @@ void AbstractImageView::setZoomToFit(bool on)
 {
     d->mZoomToFit = on;
     if (on) {
+        d->mZoomToFill = false;
         setZoom(computeZoomToFit());
     }
     // We do not set zoom to 1 if zoomToFit is off, this is up to the code
@@ -250,11 +277,12 @@ void AbstractImageView::setZoomToFit(bool on)
     zoomToFitChanged(d->mZoomToFit);
 }
 
-void AbstractImageView::setZoomToFill(bool on)
+void AbstractImageView::setZoomToFill(bool on, const QPointF& center)
 {
     d->mZoomToFill = on;
     if (on) {
-        setZoom(computeZoomToFill());
+        d->mZoomToFit = false;
+        setZoom(computeZoomToFill(), center);
     }
     // We do not set zoom to 1 if zoomToFit is off, this is up to the code
     // calling us. It may went to zoom to some other level and/or to zoom on
@@ -262,6 +290,11 @@ void AbstractImageView::setZoomToFill(bool on)
     zoomToFillChanged(d->mZoomToFill);
 }
 
+const QPixmap& AbstractImageView::alphaBackgroundTexture() const
+{
+    return d->mAlphaBackgroundTexture;
+}
+
 void AbstractImageView::resizeEvent(QGraphicsSceneResizeEvent* event)
 {
     QGraphicsWidget::resizeEvent(event);
@@ -335,24 +368,8 @@ qreal AbstractImageView::computeZoomToFill() const
 void AbstractImageView::mousePressEvent(QGraphicsSceneMouseEvent* event)
 {
     QGraphicsItem::mousePressEvent(event);
-    if (event->button() == Qt::MiddleButton) {
-        bool value = !zoomToFit();
-        setZoomToFit(value);
-        if (!value) {
-            setZoom(1., event->pos());
-        }
-        return;
-    }
 
-    if (event->modifiers() & Qt::ControlModifier) {
-        if (event->button() == Qt::LeftButton) {
-            zoomInRequested(event->pos());
-            return;
-        } else if (event->button() == Qt::RightButton) {
-            zoomOutRequested(event->pos());
-            return;
-        }
-    }
+    d->checkAndRequestZoomAction(event);
 
     // Prepare for panning or dragging
     if (event->button() == Qt::LeftButton) {
@@ -487,6 +504,8 @@ void AbstractImageView::mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event)
     if (event->modifiers() == Qt::NoModifier && event->button() == Qt::LeftButton) {
         toggleFullScreenRequested();
     }
+
+    d->checkAndRequestZoomAction(event);
 }
 
 QPointF AbstractImageView::imageOffset() const
@@ -592,4 +611,10 @@ void AbstractImageView::applyPendingScrollPos()
     d->adjustScrollPos();
 }
 
+void AbstractImageView::resetDragCursor()
+{
+    d->mLastDragPos = QPointF();
+    updateCursor();
+}
+
 } // namespace
